#!/bin/bash
# rcrsn51 2012-07-01
# jamesbond Jan 2013 - fixes

[ $(id -u) -ne 0 ] && exec gtksu "Savefile Argument Builder" "$0" "$@"

export MAINDIALOG='
<window title="Savefile Argument Builder">
<vbox>
  <frame Instructions>
    <text><label>Use this applet if you have created a savefile           </label></text>
    <text><label>but your bootloader cannot find it.                            </label></text>
    <text><label>1. Mount the required partition(s).                               </label></text>
    <text><label>2. Move your savefile to the correct location.             </label></text>
  </frame>
  <frame 3. Drag your savefile into this box>
    <hbox>
      <entry>
        <variable>SAVEFILE</variable>
      </entry>
    </hbox>
  </frame>
  <frame 4. Select the device type>
    <hbox>
      <radiobutton> 
        <variable>HDD</variable>
       <label>Hard Drive (device)</label>
     </radiobutton>
     <radiobutton> 
       <variable>USB</variable>
       <label>USB (uuid)</label>
     </radiobutton> 
     <text><label>"                                            "</label></text>
    </hbox>
  </frame>
  <hbox>
    <button><label>Next</label></button>
    <button cancel></button>
  </hbox>
</vbox>
</window>
'
export REPORTDIALOG='
<window title="Savefile Argument Builder">
<vbox>
  <frame Here is your savefile argument>
    <text><label>1. Leave this window open.                                             </label></text>
    <text><label>2. Use the Ctrl-A, Ctrl-C and Ctrl-V keys to copy and     </label></text>
    <text><label>paste it into your GRUB menu.lst file.  Add it to the</label></text>
     <text><label>end of the "kernel" line.                                           </label></text>
    <text><label>3. For a USB syslinux.cfg file, add it to the "append" line.</label></text>
    <entry><input>cat /tmp/savefile-argument.txt</input></entry>
  </frame>
  <hbox>
    <button><label>Quit</label></button>
  </hbox>
</vbox>
</window>
'

I=$IFS; IFS=""
for STATEMENTS in  $(gtkdialog --program MAINDIALOG); do
  eval $STATEMENTS
done
IFS=$I

[ "$EXIT" = "Cancel" -o "$EXIT" = "abort" ] && exit 1

# foolproof way to split find savedevice and savefile path
mountpoint= prevpath=
savefile=${SAVEFILE#/}
until [ "$prevpath" = "$savefile" ]; do 
	mountpoint=${mountpoint}/${savefile%%/*}
	prevpath=$savefile
	savefile=${savefile#*/}
	#echo $mountpoint -- $fullpath
	busybox mountpoint -q $mountpoint && break
done
partition=$(busybox mountpoint -n $mountpoint | awk '{print $1}')

if [ ${partition%/*} ] && [ ${partition%/*} == "/dev/mapper" ]; then # LVM, translate to /dev/dm-x
	dmdev=$(ls -l /dev/mapper 2> /dev/null | awk -v dmdev=${partition##*/} '$10 == dmdev {print "/dev/dm-" $6; exit; }')		
	partition=$dmdev
fi

if [ "$USB" = "true" ]; then
	uuid=$(blkid -s UUID -o value $partition)
	if [ -z "$uuid" ]; then
		Xdialog --title " " --msgbox "I could not identify the UUID of this savefile!" 0 0
		exit 1
	fi
fi

if [ "$HDD" = "true" ]; then
  ARGUMENT="savefile=direct:device:"${partition#/dev/}":"$savefile
else
  ARGUMENT="savefile=ram:uuid:"$uuid":"$savefile" waitdev=5"
fi

echo $ARGUMENT > /tmp/savefile-argument.txt

I=$IFS; IFS=""
for STATEMENTS in  $(gtkdialog3 --program REPORTDIALOG); do
  eval $STATEMENTS
done
IFS=$I
