#!/bin/ash
# choose locale for user
# Copyright (C) James Budiono 2012
# License: GNU GPL Version 3 or later

### configuration
APPTITLE="Fatdog64 Locale Selector"
SUPPORTED_GLIBC_LOCALES=/usr/share/i18n/SUPPORTED
LOCALE_DEF_DIR=/usr/share/i18n/locales
LOCALE_DIR=/usr/lib/locale
LANG_CONFIG=$FATDOG_STATE_DIR/language	# read by /etc/profile and xwin

# get list of all supported locales - this is an extra long pipeline :)
supported_locales() {
	index=0
	while read -r p; do
		case $p in 
			\#*|SUPPORTED*) ;;	# ignore these
			*)	# read the locale / charmap combination
				index=$(( index + 1))
				p=${p% \\}	# remove training space and backslash
				src=${p%%/*}; src=${src%%.*}
				
				# only process if we have the source file
				if [ -e $LOCALE_DEF_DIR/$src ]; then
					# locale and charmaps
					echo -n "${p%%/*}|${p##*/}|"
					
					# read the source for title (description), language, and territory (country)
					while read -r q ; do
					case $q in
							title*|language*) echo -n "\"${q#*\"}|" ;;
							territory*) echo "\"${q#*\"}"; break ;;
						esac
					done < $LOCALE_DEF_DIR/$src
				fi
				;;
		esac
	done < $SUPPORTED_GLIBC_LOCALES | tr -d '"' | 
	awk -F"|" '
	# transliterate columns
	# input:  locale|charmap|title|language|territory
	#         $1     $2      $3    $4       $5
	# output: language|country|locale|charmap|description
	{ print   $4     "|" $5  "|" $1 "|" $2  "|" $3}' | 
	sort -f |
	awk -F"|" '
	# format for Xdialog tree output
	# input: language|country|locale|charmap|description
	#        $1       $2      $3     $4      $5
	{
		if ( $1 != language ) {
			print "\"" $1 "\"", "\"" $1 "\"", "off", 0
			language=$1
			country=""
		}				
		if ( $2 != country ) {
			print "\"" $2 "\"", "\"" $2 "\"", "off", 1
			country=$2
		}
		print "\"" $3 "+" $4 "\"", "\"" $3 " - " $5 "\"", "off", 2
	}
	'
}

# --treeview <text> <height> <width> <list height> <tag1> <item1> <status1> <item_depth1> {<help1>}... 
if selection=$(eval Xdialog --stdout --title \"$APPTITLE\" \
             --backtitle \"Current locale is \'$LANG\'\" \
             --treeview \"Select your locale\" 30 80 0 $(supported_locales) ); then
	locale=${selection%+*}; source=${locale%.*}
	charmap=${selection#*+}
	#echo $locale $source $charmap
	case $selection in *+*) ;; *)
		Xdialog --title "$APPTITLE" --infobox "You need to choose the specific locale; not only the language or the country." 0 0 10000
		exec "$0" 
	esac
	
	locale_dir=$(echo $locale | sed 's/UTF-8/utf8/')
	if [ ! -e $LOCALE_DIR/$locale_dir ]; then
		# locale not yet compiled, need to generate it
		if [ $(id -u) -ne 0 ]; then gtksu "Create new locale definition" localedef -f $charmap -i $source --no-archive $locale 
		else localedef -f $charmap -i $source --no-archive $locale 
		fi
		
		# check that it is actually created now, only if it is we set the locale
		if [ $? -eq 0 ]; then
			echo $locale > $LANG_CONFIG; ok=ok
		fi
	else
		echo $locale > $LANG_CONFIG; ok=ok
	fi
fi

if [ $ok ]; then 
	Xdialog --title "$APPTITLE" --yesno "Your new locale will be set to $locale after you restart X server.
Locale configuration is stored in $LANG_CONFIG.\n\n
Do you want to restart X server now?" 0 0 && wmexit restart
else Xdialog --title "$APPTITLE" --infobox "Cancelled, nothing is changed." 0 0 10000
fi

