#!/bin/dash
# drive icon display daemon
# Copyright (C) James Budiono 2013, 2015
# License: GNU GPL Version 3 or later
#
# Version 1 - kick-start drive icon display and then quit
# Version 2 - this one runs as a daemon and manages the drive icons
# Version 3 - rox icons now fully managed here, not by udev-handler anymore
#

### configurations
# the following must be identical with those in udev-handler
UDEV_DRIVE_ICON_ROOT=/tmp/udev-fatdog-drive-icon
UDEV_DRIVE_ICON_EVENTS=$UDEV_DRIVE_ICON_ROOT/events
UDEV_DRIVE_ICON_DEVICES=$UDEV_DRIVE_ICON_ROOT/devices
UDEV_EVENT_COUNTER=$UDEV_DRIVE_ICON_ROOT/counter
COUNTER_MAX=100  # max number of queued events

UDEV_MAX_WAIT=30 # in seconds, wait time for udev-handler to get ready
PINBOARD_FILE=$HOME/.config/rox.sourceforge.net/ROX-Filer/PuppyPin
DRIVE_ICON_ROOT=/tmp/fatdog-drive-icons.$USER

DEBUG_FILE=$DRIVE_ICON_ROOT/log
DEBUG=

# get the rox functions
. /usr/sbin/fatdog-drive-icon-roxlib.sh # create_rox_app, rox_add_icon, rox_remove_icon, get_free_coord
. $EVENTMANAGER_CONFIG	# override default settings in get_free_coord

# output $@ to debug file
log_debug() {
	[ "$DEBUG" ] && echo "$@" >> $DEBUG_FILE
}

# $1 dev (without /dev)
action_add() {
	if [ -e $UDEV_DRIVE_ICON_DEVICES/$1 ]; then
		. $UDEV_DRIVE_ICON_DEVICES/$1 # DRIVENAME, DRIVE_TYPE, DEVNAME, SUMMARY, VOLABEL		
		mkdir -p "$DRIVE_ICON_ROOT/$DRIVENAME"
		create_rox_app "$DRIVE_ICON_ROOT/$DRIVENAME" "$DRIVE_TYPE" "$DEVNAME" "$SUMMARY"
		get_free_coord $PINBOARD_FILE $ICON_ALIGNMENT # returnx COORD_X, COORD_Y
		rox_add_icon "$DRIVE_ICON_ROOT/$DRIVENAME" $COORD_X $COORD_Y "$(get_icon_label $DRIVENAME "$VOLABEL")" "click $DEVNAME"
		fatdog-drive-icon-refresh-icon.sh $DEVNAME		
	fi
}

# $1 dev (without /dev)
action_remove() {
	rox_remove_icon $DRIVE_ICON_ROOT/$1
	rm -rf $DRIVE_ICON_ROOT/$1
}

################# main ###################

# 1. wait for udev to get ready
while ! [ -e $UDEV_EVENT_COUNTER ] && [ $UDEV_MAX_WAIT -gt 0 ]; do
	sleep 1
	UDEV_MAX_WAIT=$(( $UDEV_MAX_WAIT - 1 ))
done
# if still not ready, just leave
! [ -e $UDEV_EVENT_COUNTER ] && echo "udev not ready, bailing out" && exit 

# 2. displaying existing devices
ls -v $UDEV_DRIVE_ICON_DEVICES | while read -r p; do action_add $p; done

# 3. now handle future actions from udev handler
read -r counter1 < $UDEV_EVENT_COUNTER
while :; do
	. $EVENTMANAGER_CONFIG # refresh at every run
	counter2=
	while [ -z "$counter2" ]; do sleep 0.1; read -r counter2 < $UDEV_EVENT_COUNTER; done
	while [ $counter1 -ne $counter2 ]; do
		counter1=$(( $counter1 + 1 ))
		[ $counter1 -gt $COUNTER_MAX ] && counter1=0
			
		read action dev < $UDEV_DRIVE_ICON_EVENTS/$counter1
		log_debug $action $dev
		case $action in
			add|change)	action_remove $dev; action_add $dev ;;
			remove)	action_remove $dev ;;
		esac
	done
	
	# wait for further udev events	
	counter2=
	while [ -z "$counter2" ]; do sleep 0.1; read -r counter2 < $UDEV_EVENT_COUNTER; done
	[ $counter1 -eq $counter2 ] && inotifywait -qq -e modify $UDEV_EVENT_COUNTER
done
