#!/bin/dash
# Login Manager - sets login mode for Fatdog
#
# Copyright (C) James Budiono 2012, 2013
# License: GNU GPL Version 3 or later
#
# Note: must run as root

### configuration
APPTITLE="Fatdog64 Login Manager"

######### helpers ########

add_logout_text() {
	# change "Restart X" in openbox
	for p in /etc/xdg/openbox/menu.xml $USERHOME/.config/openbox/menu.xml; do
		sed -i -e 's/label="Restart X server"/label="Logout"/; s|<execute>restartwm</execute>|<execute>wmexit logout</execute>|' $p
	done
	    
	# change "Quit X" in lxpanel
	for p in /usr/share/lxpanel/profile/default/panels/panel $USERHOME/.config/lxpanel/default/panels/panel; do
		sed -i -e 's/name=Quit X server/name=Logout/; s/wmexit terminal/wmexit logout/' $p
	done	
	
	# change "Exit to prompt" in jwm
	sed -i -e 's/-Exit to prompt/-Logout/; s/wmexit terminal/wmexit logout/' /usr/bin/jwm_menu_create
	
	# change "Restart X" in razor-panel
	sed -i -e 's/^Restart *X/Logout/; s/restartwm/wmexit logout/' /etc/xdg/razor/bottom-menu.conf
}

remove_logout_text() {
	# undo logout openbox menu - back to Restart X
	for p in /etc/xdg/openbox/menu.xml $USERHOME/.config/openbox/menu.xml; do
		sed -i -e 's/label="Logout"/label="Restart X server"/; s|<execute>wmexit logout</execute>|<execute>restartwm</execute>|' $p
	done
	
	# undo logout lxpanel menu - back to Quit X
	for p in /usr/share/lxpanel/profile/default/panels/panel $USERHOME/.config/lxpanel/default/panels/panel; do
		sed -i -e 's/name=Logout/name=Quit X server/; s/wmexit logout/wmexit terminal/' $p
	done
	
	# undo logout jwm menu - back to Exit to prompt
	sed -i -e 's/-Logout/-Exit to prompt/; s/wmexit logout/wmexit terminal/' /usr/bin/jwm_menu_create
	
	# undo logout razor-panel menu - back to Restart X
	sed -i -e 's/^Logout/Restart X/; s/wmexit logout/restartwm/' /etc/xdg/razor/bottom-menu.conf
}

enable_autologin() {
	sed -i -e '/^tty1:/ s|respawn:.*|respawn:/sbin/getty -n -l /bin/autologin 38400 tty1|' /etc/inittab
}

disable_autologin() {
	sed -i -e '/^tty1:/ s|respawn:.*|respawn:/sbin/getty 38400 tty1|' /etc/inittab
}

remove_slim() {
	sed -i -e '\_/usr/bin/slim_ d' /etc/rc.d/rc.local
}

add_slim() {
	remove_slim	# prevent duplicates
	echo '/usr/bin/slim -d' >> /etc/rc.d/rc.local
}

get_current_login_mode() {
	MODE="console"
	grep -q /usr/bin/slim /etc/rc.d/rc.local && MODE="graphical"
	grep -q autologin /etc/inittab && MODE="autologin"
}

#$1-mode 
set_login_mode() {
	case $1 in
		console)	disable_autologin; add_logout_text; remove_slim ;;
		graphical)	disable_autologin; add_logout_text; add_slim ;;
		autologin)	enable_autologin;  remove_logout_text; remove_slim ;;
	esac
}

########### main #############
export USERHOME=$(awk -F: -v user=$USER '$1==user {print $6}' /etc/passwd) # the user's home
[ $(id -u) -ne 0 ] && exec gtksu "$APPTITLE" "$0" "$@"

get_current_login_mode	# return MODE

status_console=off status_graphical=off status_autologin=off
eval status_$MODE=on

if NEWMODE=$(Xdialog --stdout --title "$APPTITLE" --no-tags --radiolist "Current login mode is: $MODE.
Please choose the new login mode. Takes effect at next boot." 12 80 0 \
	autologin "Autologin - no password necessary" $status_autologin \
	graphical "Graphical login" $status_graphical \
	console "Console login" $status_console); then
	if [ $NEWMODE != $MODE ]; then
		set_login_mode $NEWMODE
		Xdialog --title "$APPTITLE" --msgbox "Login mode has been changed to '$NEWMODE' and will take effect at next boot." 0 0 10000
		[ $MODE = "autologin" ] && echo -e '\a' > /dev/console && 
		Xdialog --title "Warning" --msgbox "You are disabling autologin.
At next boot, you are required to provide a password before you can login to the system.
Make sure you know the password for the user you are going to use, and the root password too.
If you don't know, you can set the passwords now using the User Manager from Control Panel.
If you have not changed anything, the default root password is 'woofwoof'." 0 0 90000
		exit
	fi
fi
Xdialog --title "$APPTITLE" --msgbox "Nothing is changed. The login mode stays as '$MODE'". 0 0 10000
